@@ -1,5 +1,6 @@
 # frozen_string_literal: true
 
+require 'puppet/util/json'
 #
 # parsejson.rb
 #
@@ -14,13 +15,14 @@ module Puppet::Parser::Functions
 
     > *Note:*
       The optional second argument can be used to pass a default value that will
-      be returned if the parsing of YAML string have failed.
+      be returned if the parsing of the JSON string failed or if the JSON parse
+      evaluated to nil.
   DOC
   ) do |arguments|
     raise ArgumentError, 'Wrong number of arguments. 1 or 2 arguments should be provided.' unless arguments.length >= 1
 
     begin
-      PSON.load(arguments[0]) || arguments[1]
+      Puppet::Util::Json.load(arguments[0]) || arguments[1]
     rescue StandardError => e
       raise e unless arguments[1]
       arguments[1]
